 [![Travis build](https://travis-ci.org/inspirehep/harvesting-kit.svg?branch=master)](https://travis-ci.org/inspirehep/harvesting-kit) [![Coverage Status](https://img.shields.io/coveralls/inspirehep/harvesting-kit.svg)](https://coveralls.io/r/inspirehep/harvesting-kit)


Harvesting-Kit
==============

A kit containing various utilities and scripts related to content harvesting used in [Invenio Software]( http://invenio-software.org) instances such as INSPIRE and SCOAP3.

Primarily it focuses on converting certain XML meta-data standards, such as [NLM](http://www.nlm.nih.gov/tsd/cataloging/mainpge.html) and [JATS](http://jats.nlm.nih.gov/).


Install
=======

`pip install HarvestingKit`


